**************************************************************
**** Figure 1 Total Amount of USD Debt Issuance (2009-2017)
**************************************************************
use aggregate_data_JMCB.dta, clear
twoway (tsline issusdv_bond) (tsline naiss15, lpattern(dash)), ytitle("USD debt issuance (billion dollars)") xlabel(2009(1)2017) graphregion(color(white)) xtitle("")

clear

***************************************************
***************************************************
use firm_data_JMCB.dta, clear

** firm-level variables
gen logvroa2_3y=ln(vroa2_3y)
gen logvroa2_5y=ln(vroa2_5y)

gen logvcapx_ta_3y =ln(vcapx_ta_3y)
gen logvcapx_ta_5y =ln(vcapx_ta_5y)

gen logvol_rd_3y=ln(vol_rd_3y)
gen logvol_rd_5y=ln(vol_rd_5y)

gen logvroe2_3y=ln(vroe2_3y)
gen logvroe2_5y=ln(vroe2_5y)

gen iss_nonusd=isslc
replace iss_nonusd=1 if issfc==1

gen logissusdv=ln(1+issusdv)
gen logissnonusdv=ln(1+isslcv+issfcv)

gen debt_at=debtusdv/(1000000*at)
replace debt_at=. if debt_at>1

gen debtlc_at=debtlcv/(1000000*at)
replace debtlc_at=. if debtlc_at>1
gen debtfc_at=debtfcv/(1000000*at)
replace debtfc_at=. if debtfc_at>1
gen debt_nonusd_at=debtlc_at+debtfc_at

gen tot_debt=dlc+dltt

gen size=ln(at)
gen leverage=lt/at
gen gpm=(revt-cogs)/revt if cogs>0
gen wc_ta=wcap/at
gen cash_ta=chee/at

xtset firmid year
by firmid: gen capx_ta=capx/l.at

gen mrpk=revt/ppent if ppent>0
gen logmrpk=ln(mrpk)

gen roa=nicon/at

gen roe=nicon/teq if teq>0

winsor2 size leverage gpm wc_ta cash_ta capx_ta logmrpk roa roe, replace
winsor2 capxta_3y capxta_5y logmrpk_3y logmrpk_5y roa_3y roa_5y roe_3y roe_5y, replace

egen cyi=group(iso2 sic2 year)
bys cyi: egen revt_ind=total(revt)
gen mktsh=revt/revt_ind

bys cyi: gen n=_N

gen ci_u=1/sumdiff_mktsh
label var ci_u "unweighted distance"
gen logci_u=ln(ci_u)

gen ci_w3=1/sumdiff_mktsh_w3
label var ci_w3 "weighted by issuance value/industry total asssets"
gen logci_w3=ln(ci_w3)

bys cyi: egen n_issuers=total(issusd)
gen avgdiff_mktsh=sumdiff_mktsh/n_issuers
gen ci_avg=1/avgdiff_mktsh
label var ci_avg "average distance"
gen logci_avg=ln(ci_avg)

gen ci_hhi=1/hhi_s
label var ci_hhi "HHI"
gen logci_hhi=ln(ci_hhi)

gen ci_hhi_ex=1/hhi_s_ex
label var ci_hhi_ex "HHI excluding the nonisser itself"
gen logci_hhi_ex=ln(ci_hhi_ex)

xtset firmid year
by firmid: gen l_issusd=l.issusd
by firmid: gen l_iss_nonusd=l.iss_nonusd
by firmid: gen l_isslc=l.isslc
by firmid: gen l_issfc=l.issfc
by firmid: gen l_size=l.size
by firmid: gen l_leverage=l.leverage
by firmid: gen l_gpm=l.gpm
by firmid: gen l_wc_ta=l.wc_ta
by firmid: gen l_cash_ta=l.cash_ta
by firmid: gen l_roa=l.roa
by firmid: gen l_pr_us=l.pr_us
by firmid: gen l_dlogusd_broad=l.dlogusd_broad

by firmid: egen cum_debtusd=sum(debtusdv)
by firmid: gen nonissuer1=1 if l.cum_debtusd==0
by firmid: gen nonissuer2=1 if f2.cum_debtusd==0

** country-level variables
gen pr_diff=pr-pr_us
gen creditgap_high=(creditgap_q3>=2) if !missing(creditgap_q3)

xtset firmid year
by firmid: gen l_std_e_kai=l.std_e_kai
by firmid: gen l_std_e_boi=l.std_e_boi
by firmid: gen l_std_e_eqi=l.std_e_eqi
by firmid: gen l_std_e_cum_Capital_FX=l.std_e_cum_Capital_FX
by firmid: gen l_std_e_cum_LFC=l.std_e_cum_LFC
by firmid: gen l_std_e_cum_LFX=l.std_e_cum_LFX
by firmid: gen l_std_e_cum_LCG_Corp=l.std_e_cum_LCG_Corp
by firmid: gen l_std_e_cum_DSTI=l.std_e_cum_DSTI
by firmid: gen l_std_e_inv_ltv=l.std_e_inv_ltv

** country-industry-year level
bys cyi: egen msize_ciy=mean(size)
bys cyi: egen mgpm_ciy=mean(gpm)
bys cyi: egen mleverage_ciy=mean(leverage)
bys cyi: egen mwc_ta_ciy=mean(wc_ta)
bys cyi: egen mcash_ta_ciy=mean(cash_ta)

replace avg_rd_3y=100*avg_rd_3y
bys cyi: egen rd3_p95=pctile(avg_rd_3y), p(95)
bys cyi: egen rd3_p50=pctile(avg_rd_3y), p(50)
bys cyi: egen rd3_p5=pctile(avg_rd_3y), p(5)
gen dispersion_rd3=rd3_p95-rd3_p5
gen uprisk_rd3=rd3_p95-rd3_p50
gen downrisk_rd3=rd3_p50-rd3_p5
gen skew_rd3=uprisk_rd3-downrisk_rd3
gen kellyskew_rd3=skew_rd3/dispersion_rd3

bys cyi: egen rd3_p90=pctile(avg_rd_3y), p(90)
bys cyi: egen rd3_p10=pctile(avg_rd_3y), p(10)
gen dis10_rd3=rd3_p90-rd3_p10
gen up10_rd3=rd3_p90-rd3_p50
gen down10_rd3=rd3_p50-rd3_p10
gen skew10_rd3=up10_rd3-down10_rd3
gen kellyskew10_rd3=skew10_rd3/dis10_rd3

bys cyi: egen iss_tot=total(issusdv)
bys cyi: egen td_tot=total(1000000*tot_debt)
gen share_iss_td=iss_tot/(td_tot)
replace share_iss_td=. if share_iss_td>1

bys cyi: egen isslc_tot=total(isslcv)
bys cyi: egen issfc_tot=total(issfcv)
gen iss_nonusd_tot=isslc_tot+issfc_tot
gen share_iss_nonusd_td=iss_nonusd_tot/(td_tot)
replace share_iss_nonusd_td=. if share_iss_nonusd_td>1

egen cyear=group(iso2 year)
egen indyr=group(sic2 year)

egen csy=group(iso2 sector year)
egen temp=group(iso2 sector)
bys temp: egen mli=mean(l_issusd) 
replace temp=. if mli==0
egen cs=group(temp)
drop temp mli

xtset firmid year

*********************************************************
** Table 1. The effect of USD interest rate on issuance
*********************************************************
xi: probit issusd pr_us pr dlogusd_broad iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, replace ctitle("baseline") keep(pr_us pr dlogusd_broad) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y) 

xi: probit issusd pr_us pr dlogusd_broad creditgap_high iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("+creditgap") keep(pr_us pr dlogusd_broad creditgap_high) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y) 

xi: probit issusd pr_us pr dlogusd_broad creditgap_high cds_sov iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("+cds_sov") keep(pr_us pr dlogusd_broad creditgap_high cds_sov) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y)

xi: probit issusd pr_us pr dlogusd_broad creditgap_high cds_sov rgdpg iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("+rgdpg") keep(pr_us pr dlogusd_broad creditgap_high cds_sov rgdpg) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y)

xi: probit issusd tb10 pr dlogusd_broad iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("tb10") keep(tb10 pr dlogusd_broad) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y) 

xi: probit issusd tb10 pr dlogusd_broad creditgap_high iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("tb10_creditgap") keep(tb10 pr dlogusd_broad creditgap_high) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y) 

xi: probit issusd tb10 pr dlogusd_broad creditgap_high cds_sov iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("tb10_cds_sov") keep(tb10 pr dlogusd_broad creditgap_high cds_sov) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y)

xi: probit issusd tb10 pr dlogusd_broad creditgap_high cds_sov rgdpg iss_nonusd size leverage gpm wc_ta cash_ta i.cs if year>=2008&year<=2016, cluster(cs)
outreg2 using table1, ctitle("tb10_rgdpg") keep(tb10 pr dlogusd_broad creditgap_high cds_sov rgdpg) dec(3) nocons word addstat(Pseudo R2, e(r2_p)) addtext(Controls, Y, Country-Sector FE,Y)

****************************************************
** Table 2. Basic results on corporate risk-taking
****************************************************
reghdfe logvroa2_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
gen sample=1 if e(sample)==1
outreg2 using table2, replace ctitle("vroa2_3y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3) nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd  

reghdfe logvcapx_ta_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vcapx_ta_3y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd 

reghdfe logvol_rd_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vol_rd_3y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd  

reghdfe logvroe2_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vroe2_3y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd  

reghdfe logvroa2_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vroa2_5y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3) nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd  

reghdfe logvcapx_ta_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vcapx_ta_5y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd  

reghdfe logvol_rd_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vol_rd_5y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd 

reghdfe logvroe2_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table2, ctitle("vroe2_5y") keep(l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.issusd=l.iss_nonusd 

*********************************************
**** Table 3. Issuance size vs. debt stock
*********************************************
reghdfe logvroa2_3y l.logissusdv l.logissnonusdv l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table3, replace ctitle("logissusdv") keep(l.logissusdv l.logissnonusdv) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.logissusdv=l.logissnonusdv

reghdfe logvroa2_3y l.debt_at l.debt_nonusd_at l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table3, ctitle("debt_at") keep(l.debt_at l.debt_nonusd_at) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.debt_at=l.debt_nonusd_at  

reghdfe logvroa2_5y l.logissusdv l.logissnonusdv l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table3, ctitle("logissusdv_5y") keep(l.logissusdv l.logissnonusdv) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y)

test l.logissusdv=l.logissnonusdv  

reghdfe logvroa2_5y l.debt_at l.debt_nonusd_at l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table3, ctitle("debt_at_5y") keep(l.debt_at l.debt_nonusd_at) dec(3)nocons word addtext(Cyear FE, Y, Indyr FE,Y) 

test l.debt_at=l.debt_nonusd_at   

// Radius Matching	
gen y_sample=size if sample==1
gen weight1=.
gen ps1=.

forvalues i = 1/72{
display `i'
capture noisily psmatch2 l_issusd l_isslc l_issfc l_size l_leverage l_gpm l_wc_ta l_cash_ta l_pr_us l_dlogusd_broad if year>=2009 & cs== `i' , out(y_sample) radius caliper(0.01) comm
if c(rc)==0 {
  replace weight1=_weight if cs== `i'
  replace ps1=_pscore if cs== `i'
  }
}

** Panel A of Table A5. Balancing test 
pstest l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 & weight1!=., treated(l_issusd) mweight(weight1) raw 

************************************************
** Table 4A. Using the radius-matched sample
************************************************
reghdfe logvroa2_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, replace ctitle("R_vroa2_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvcapx_ta_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vcapx_ta_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vol_rd_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroe2_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vroe2_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vroa2_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvcapx_ta_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vcapx_ta_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vol_rd_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroe2_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr)
outreg2 using table4a, ctitle("R_vroe2_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

// Kernel Mmatching
gen weight2=.
gen ps2=.
forvalues i = 1/72{
display `i'
capture noisily psmatch2 l_issusd l_isslc l_issfc l_size l_leverage l_gpm l_wc_ta l_cash_ta l_pr_us l_dlogusd_broad if year>=2009 & cs== `i' , out(y_sample) kernel comm k(epan) bw(0.01)
if c(rc)==0 {
  replace weight2=_weight if cs== `i'
  replace ps2=_pscore if cs== `i'
  }
}

** Panel B of Table A5. Balancing test 
pstest l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta  if year>=2009 & weight2!=., treated(l_issusd) mweight(weight2) raw 

************************************************
** Table 4B. Using the kernel-matched sample
************************************************
reghdfe logvroa2_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, replace ctitle("K_vroa2_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvcapx_ta_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vcapx_ta_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vol_rd_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

reghdfe logvroe2_3y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vroe2_3y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

reghdfe logvroa2_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vroa2_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvcapx_ta_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vcapx_ta_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vol_rd_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

 reghdfe logvroe2_5y l_issusd l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr)
outreg2 using table4b, ctitle("K_vroe2_5y") keep(l_issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

********************************
**** Figure 2. Placebo tests
********************************
preserve 
keep if sample==1
gen issusd_fake=.
tempname placebo 
postfile `placebo' reps coeff se using placebo.dta 
set seed 123456
quietly  forvalues i=1/5000 {
      shufflevar issusd 
	  xtset firmid year
	  replace issusd_fake=issusd_shuffled
      quietly reghdfe logvroa2_3y l.issusd_fake  l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
	  post `placebo' (`i') (`=_b[l.issusd_fake]') (`=_se[l.issusd_fake]') 
}
postclose `placebo' 
restore

**** plot the coefficient distribution from the placebo test
preserve
use placebo.dta, clear
sum coeff, detail
hist coeff, kdensity normopts(lcolor(red) lpattern(dash)) graphregion(color(white)) xtitle("")
restore

*************************************************
**** Table 5. Amplification Effects
*************************************************
xtset firmid year

** (1) interaction effects
reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, replace ctitle("pdlev_basic") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.effr_ws l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_effr") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.effr_ws) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.dlogvix l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_vix") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.dlogvix) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.dlogusd_broad l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_USDbroad") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.dlogusd_broad) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.gfc_stdz l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_GFC") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.gfc_stdz) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.pr_diff c.l.issusd#c.l.gs l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_pr_gs") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.pr_diff c.l.issusd#c.l.gs) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.cds_sov l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_cds") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.cds_sov) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.creditgap_high l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_creditgdp") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.creditgap_high) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.rgdpg l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table5, ctitle("pdlev_rgdpg") keep(l.issusd c.l.issusd#c.l.pdlev c.l.issusd#c.l.rgdpg) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

********************************************************
**** Table 6a. Overinvestment: short-run, full sample
********************************************************
reghdfe capx_ta l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table6a, replace ctitle("capx_ta") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table6a, ctitle("logmrpk") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table6a, ctitle("roa") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table6a, ctitle("roe") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

**********************************************************
****** Table 7a. Overinvestment: longer-run, full sample
**********************************************************
reghdfe capxta_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, replace ctitle("capxta_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("logmrpk_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("roa_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("roe_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe capxta_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("capxta_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("logmrpk_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("roa_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table7a, ctitle("roe_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

***************************************************
**** Table 6b. Overinvestment: short-run, radius
***************************************************
reghdfe capx_ta l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table6b, replace ctitle("capx_ta") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table6b, ctitle("logmrpk") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table6b, ctitle("roa") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table6b, ctitle("roe") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

***************************************************
**** Table 7b. Overinvestment: medium-run, radius
***************************************************
reghdfe capxta_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, replace ctitle("capxta_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("logmrpk_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("roa_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("roe_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe capxta_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("capxta_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("logmrpk_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("roa_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight1], absorb(cyear indyr) 
outreg2 using table7b, ctitle("roe_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

***************************************************
**** Table 6c. Overinvestment: short-run, kernel 
***************************************************
reghdfe capx_ta l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table6c, replace ctitle("capx_ta") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table6c, ctitle("logmrpk") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table6c, ctitle("roa") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table6c, ctitle("roe") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

*******************************************************
**** Table 7c. Overinvestment: medium-run, kernel 
*******************************************************
reghdfe capxta_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, replace ctitle("capxta_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("logmrpk_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("roa_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("roe_3y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe capxta_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("capxta_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logmrpk_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("logmrpk_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roa_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("roa_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe roe_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 [aweight=weight2], absorb(cyear indyr) 
outreg2 using table7c, ctitle("roe_5y") keep(l.issusd) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

****************************************************************************
**** Table 8. The Effects of Capital Controls & Macro-Prudential Policies
****************************************************************************
set seed 123456

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_kai l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, replace ctitle("kai") keep(l_issusd c.l_issusd#c.l_std_e_kai) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_boi l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr)
outreg2 using table8, ctitle("boi") keep(l_issusd c.l_issusd#c.l_std_e_boi) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_eqi l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr)
outreg2 using table8, ctitle("eqi") keep(l_issusd c.l_issusd#c.l_std_e_eqi) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_cum_Capital_FX l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr)
outreg2 using table8, ctitle("Capital_FX") keep(l_issusd c.l_issusd#c.l_std_e_cum_Capital_FX) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_cum_LFC l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, ctitle("LFC") keep(l_issusd c.l_issusd#c.l_std_e_cum_LFC) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_cum_LFX l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, ctitle("LFX") keep(l_issusd c.l_issusd#c.l_std_e_cum_LFX) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_cum_LCG_Corp l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, ctitle("LCG_Corp") keep(l_issusd c.l_issusd#c.l_std_e_cum_LCG_Corp) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_cum_DSTI l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, ctitle("DSTI") keep(l_issusd c.l_issusd#c.l_std_e_cum_DSTI) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

bootstrap _b, reps(1000): reghdfe logvroa2_3y l_issusd c.l_issusd#c.l_std_e_inv_ltv l_iss_nonusd l_size l_leverage l_gpm l_wc_ta l_cash_ta if year>=2009, absorb(cyear indyr) 
outreg2 using table8, ctitle("inv_LTV") keep(l_issusd c.l_issusd#c.l_std_e_inv_ltv) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

****************************************
**** Table 9. Spillovers to Nonissuers 
****************************************
** Broadly-defined 
reghdfe logvroa2_3y l.logci_u l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer1==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, replace ctitle("1_ci_u") keep(l.logci_u) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.logci_w3 l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer1==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("1_ci_w3") keep(l.logci_w3) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.logci_avg l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer1==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("1_ci_avg") keep(l.logci_avg) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.logci_hhi l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer1==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("1_ci_hhi") keep(l.logci_hhi) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

** Narrowly-defined
reghdfe logvroa2_3y l.logci_u l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer2==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("2_ci_u") keep(l.logci_u) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_3y l.logci_w3 l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer2==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("2_ci_w3") keep(l.logci_w3) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

reghdfe logvroa2_3y l.logci_avg l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer2==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("2_ci_avg") keep(l.logci_avg) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

reghdfe logvroa2_3y l.logci_hhi l.iss_nonusd l.mktsh l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009 & nonissuer2==1, absorb(cyear indyr) cluster(cyi)
outreg2 using table9, ctitle("2_ci_hhi") keep(l.logci_hhi) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y)

****************************************************************************
**** Table 10. The Effect on Cross-Sectional Distribution of Stock Return
****************************************************************************
egen ci=group(iso2 sic2)

preserve
duplicates drop cyi, force
xtset ci year

reghdfe downrisk_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, replace ctitle("downrisk_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe uprisk_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("uprisk_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe skew_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("skew_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe kellyskew_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("kellyskew_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe down10_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("down10_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe up10_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("up10_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe skew10_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("skew10_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe kellyskew10_rd3 l.share_iss_td l.share_iss_nonusd_td l.msize_ciy l.mleverage_ciy  l.mgpm_ciy l.mwc_ta_ciy l.mcash_ta_ciy if year>=2009 & n>=2, absorb(cyear indyr) cluster(ci)
outreg2 using table10, ctitle("kellyskew10_rd3") keep(l.share_iss_td) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

restore

*****************************************************
** Table A3. Aggregate USD Debt Statistics
*****************************************************
gen issusdratio=(issusd)/(issusd+isslc+issfc)*100 if issusd==1|isslc==1|issfc==1

gen logissusdv2=ln(issusdv) if issusdv>0

gen issusdv_at=issusdv/(at*1000000) if issusdv>0
replace issusdv_at=. if issusdv_at>1

gen usddebt_at=debtusdv/(1000000*at) if debtusdv>0
replace usddebt_at=. if usddebt_at>1

preserve
collapse issusdratio logissusdv2 issusdv_at usddebt_at if year>=2009,   by (year)
replace issusdratio=round(issusdratio,0.1)
replace logissusdv2=round(logissusdv2,0.001)
replace issusdv_at=round(issusdv_at,0.001)
replace usddebt_at=round(usddebt_at,0.001)
bysort year:sum issusdratio logissusdv2 issusdv_at usddebt_at if year>=2009
restore

****************************************************
**** Table A4. Country*Sector*Year FE
****************************************************
reghdfe logvroa2_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, replace ctitle("vroa2_3y") keep(l.issusd ) dec(3) nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvcapx_ta_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("vcapx_ta_3y") keep(l.issusd ) dec(3)nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvol_rd_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("vol_rd_3y") keep(l.issusd ) dec(3)nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroe2_3y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("vroe2_3y") keep(l.issusd) dec(3) nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroa2_3y l.logissusdv l.logissnonusdv l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("logissusdv") keep(l.logissusdv) dec(3)nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroa2_3y l.debt_at l.debt_nonusd_at l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("debt_at") keep(l.debt_at) dec(3)nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroa2_5y l.issusd l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("vroa2_5y") keep(l.issusd) dec(3) nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroa2_5y l.logissusdv l.logissnonusdv l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("logissusdv_5y") keep(l.logissusdv) dec(3)nocons word addtext(Country*Sector*Year FE, Y) 

reghdfe logvroa2_5y l.debt_at l.debt_nonusd_at l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(csy) cluster(cyi)
outreg2 using table_a4, ctitle("debt_at_5y") keep(l.debt_at) dec(3)nocons word addtext(Country*Sector*Year FE, Y)

*************************************************************************
**** Table A6. Amplification effect: alternative risk-taking measures
*************************************************************************
reghdfe logvcapx_ta_3y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, replace ctitle("logvcap_ta_3y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_3y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvolrd_3y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroe2_3y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvroe2_3y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroa2_5y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvroa2_5y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvcapx_ta_5y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvcap_ta_5y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvol_rd_5y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvolrd_5y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 

reghdfe logvroe2_5y l.issusd c.l.issusd#c.l.pdlev l.iss_nonusd l.size l.leverage l.gpm l.wc_ta l.cash_ta if year>=2009, absorb(cyear indyr) cluster(cyi)
outreg2 using table_a6, ctitle("logvroe2_5y") keep(l.issusd c.l.issusd#c.l.pdlev) dec(3) nocons word addtext(Controls, Y, Cyear FE, Y, Indyr FE,Y) 